summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrRotationDialogImpl.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kpresenter/KPrRotationDialogImpl.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpresenter/KPrRotationDialogImpl.h')
-rw-r--r--kpresenter/KPrRotationDialogImpl.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpresenter/KPrRotationDialogImpl.h b/kpresenter/KPrRotationDialogImpl.h
index 7741ff76..e030641b 100644
--- a/kpresenter/KPrRotationDialogImpl.h
+++ b/kpresenter/KPrRotationDialogImpl.h
@@ -37,7 +37,7 @@ class KPrRotationDialogImpl : public KDialogBase
TQ_OBJECT
public:
- KPrRotationDialogImpl( TQWidget *tqparent, const char* name = 0 );
+ KPrRotationDialogImpl( TQWidget *parent, const char* name = 0 );
~KPrRotationDialogImpl() {}
void setAngle( double angle );
@@ -68,12 +68,12 @@ class KPrCircleToggle : public TQLabel
public:
/**
* Constructor.
* @param tqparent the tqparent widget, as required by TQt.
* @param image the named image that we will use. "rotate/" is
* prepended and "dn" is appended for the checked state.
* @param id the id that will be used in the clicked signal
*/
- KPrCircleToggle(TQWidget *tqparent, const TQString &image, int id);
+ KPrCircleToggle(TQWidget *parent, const TQString &image, int id);
/// return the id which is passed in the constructor
int id() { return m_id; }
@@ -108,9 +108,9 @@ class KPrCircleGroup : public TQFrame
public:
/**
* Constructor.
* @param tqparent the tqparent widget, as required by TQt.
*/
- KPrCircleGroup(TQWidget *tqparent);
+ KPrCircleGroup(TQWidget *parent);
/**
* Set the angle the group is currently representing. If there is a child button
* that registred itself (using add()) with an ID that matches the argument angle
@@ -68,12 +68,12 @@ class KPrCircleToggle : public TQLabel
/**
* Constructor.
- * @param tqparent the tqparent widget, as required by TQt.
+ * @param parent the parent widget, as required by TQt.
* @param image the named image that we will use. "rotate/" is
* prepended and "dn" is appended for the checked state.
@@ -108,9 +108,9 @@ class KPrCircleGroup : public TQFrame
/**
* Constructor.
- * @param tqparent the tqparent widget, as required by TQt.
+ * @param parent the parent widget, as required by TQt.
*/